@@ -1,5 +1,6 @@
 from gooey import Gooey, GooeyParser
-from .main_process import main_process,get_list
+from .main_process import main_process
+from .comFuction import get_list
 
 
 @Gooey(
